@@ -25,6 +25,10 @@
 # v2014-07-25 Paco Erweiterung des Installationsscripts für Installation
 #                  bzw. Update auch für MySQL
 # v2014-08-04 Paco Berechtigung passt noch nicht ganz
+# v2014-11-24 Paco neuer Conf-Parameter EmailFontSize
+# 2015-01-10 Paco neues Installationspaket, wo nur ganz am Anfang das Datenmodell
+#                 installiert wird, der Rest wird danach vom PHP-File selbst
+#                 aktualisiert
 ######################################################################
 TARGETDIR=/srv/www/htdocs
 APPDIR=/u01/app
@@ -318,7 +322,7 @@ main() {
         chmod o+w index.php
         chmod 777 uploads
     fi
-    
+
     # Rechte setzen für log und conf
     echo "Recht <root:${GROUP}> für <conf> und <log>"
     if [ ${DEBUG} -eq 0 ]; then
@@ -358,22 +362,16 @@ main() {
                 # Datenmodell ausfuehren
                 if [ ${DBTYPE} = "oracle" ]; then
                     sqlplus ${SCHEMA}/${SCHEMA}@${SID} @create-oracle-db-model-oplist.sql
+					sqlplus ${SCHEMA}/${SCHEMA}@${SID} @update-oracle-db-model-oplist.sql
+					sqlplus ${SCHEMA}/${SCHEMA}@${SID} @merge-oracle-base-entries-oplist.sql
                 else
                     mysql -h ${DBHOST} -u ${SCHEMA} -p ${PASSWD} ${SID} < create-mysql-db-model-oplist.sql
+					mysql -f -h ${DBHOST} -u${SCHEMA} -p${PASSWD} ${SID} < update-mysql-db-model-oplist.sql
+					mysql -f -h ${DBHOST} -u${SCHEMA} -p${PASSWD} ${SID} < merge-mysql-base-entries-oplist.sql
                 fi
             fi
         fi
     fi
-    echo "Wir installieren die Updates und Inserts"
-    if [ ${DEBUG} -eq 0 ]; then
-        if [ ${DBTYPE} = "oracle" ]; then
-            sqlplus ${SCHEMA}/${SCHEMA}@${SID} @update-oracle-db-model-oplist.sql
-            sqlplus ${SCHEMA}/${SCHEMA}@${SID} @merge-oracle-base-entries-oplist.sql
-        else
-            mysql -f -h ${DBHOST} -u${SCHEMA} -p${PASSWD} ${SID} < update-mysql-db-model-oplist.sql
-            mysql -f -h ${DBHOST} -u${SCHEMA} -p${PASSWD} ${SID} < merge-mysql-base-entries-oplist.sql
-        fi
-    fi
 
     exit 0
 }
